
# sssom


**metamodel version:** 1.7.0

**version:** None


Datamodel for Simple Standard for Sharing Ontology Mappings (SSSOM)


### Classes

 * [Mapping](Mapping.md) - Represents an individual mapping between a pair of entities
 * [MappingSet](MappingSet.md) - Represents a set of mappings

### Mixins


### Slots

 * [author_id](author_id.md) - Identifies the persons or groups responsible for asserting the mappings. Recommended to be a (pipe-separated) list of ORCIDs or otherwise identifying URLs, but any identifying string (such as name and affiliation) is permissible.
 * [author_label](author_label.md) - A string identifying the author of this mapping. In the spirit of provenance, consider to use author_id instead.
 * [comment](comment.md) - Free text field containing either curator notes or text generated by tool providing additional informative information.
 * [confidence](confidence.md) - A score between 0 and 1 to denote the confidence or probability that the match is correct, where 1 denotes total confidence.
 * [creator_id](creator_id.md) - Identifies the persons or groups responsible for the creation of the mapping. The creator is the agent that put the mapping in its published form, which may be different from the author, which is a person that was actively involved in the assertion of the mapping. Recommended to be a (pipe-separated) list of ORCIDs or otherwise identifying URLs, but any identifying string (such as name and affiliation) is permissible.
 * [creator_label](creator_label.md) - A string identifying the creator of this mapping. In the spirit of provenance, consider to use creator_id instead.
 * [license](license.md) - A url to the license of the mapping. In absence of a license we assume no license.
     * [mapping set➞license](mapping_set_license.md)
 * [mapping_cardinality](mapping_cardinality.md) - A string indicating whether this mapping is from a 1:1 (the subject_id maps to a single object_id), 1:n (the subject maps to more than one object_id), n:1, 1:0, 0:1 or n:n group. Note that this is a convenience field that should be derivable from the mapping set.
 * [mapping_date](mapping_date.md) - The date the mapping was asserted. This is different from the date the mapping was published or compiled in a SSSOM file.
 * [mapping_justification](mapping_justification.md) - A mapping justification is an action (or the written representation of that action) of showing a mapping to be right or reasonable.
 * [mapping_provider](mapping_provider.md) - URL pointing to the source that provided the mapping, for example an ontology that already contains the mappings, or a database from which it was derived.
 * [mapping_set_description](mapping_set_description.md) - A description of the mapping set.
 * [mapping_set_id](mapping_set_id.md) - A globally unique identifier for the mapping set (not each individual mapping). Should be IRI, ideally resolvable.
 * [mapping_set_source](mapping_set_source.md) - A mapping set or set of mapping set that was used to derive the mapping set.
 * [mapping_set_version](mapping_set_version.md) - A version string for the mapping.
 * [mapping_source](mapping_source.md) - The mapping set this mapping was originally defined in. mapping_source is used for example when merging multiple mapping sets or deriving one mapping set from another.
 * [mapping_tool](mapping_tool.md) - A reference to the tool or algorithm that was used to generate the mapping. Should be a URL pointing to more info about it, but can be free text.
 * [mapping_tool_version](mapping_tool_version.md) - Version string that denotes the version of the mapping tool used.
 * [mappings](mappings.md) - Contains a list of mapping objects
 * [match_string](match_string.md) - Strings that are shared by subj/obj. It is recommended to indicate the fields for the match using the object and subject_match_field slots.
 * [object_category](object_category.md) - The conceptual category to which the subject belongs to. This can be a string denoting the category or a term from a controlled vocabulary.
 * [object_id](object_id.md) - The ID of the object of the mapping.
 * [object_label](object_label.md) - The label of object of the mapping
 * [object_match_field](object_match_field.md) - A tuple of fields (term annotations on the object) that was used for the match.
 * [object_preprocessing](object_preprocessing.md) - Method of preprocessing applied to the fields of the object. If different preprocessing steps were performed on different fields, it is recommended to store the match in separate rows.
 * [object_source](object_source.md) - IRI of ontology source for the object. Version IRI preferred.
 * [object_source_version](object_source_version.md) - Version IRI or version string of the source of the object term.
 * [object_type](object_type.md) - The type of entity that is being mapped.
 * [other](other.md) - Pipe separated list of key value pairs for properties not part of the SSSOM spec. Can be used to encode additional provenance data.
 * [predicate_id](predicate_id.md) - The ID of the predicate or relation that relates the subject and object of this match.
 * [predicate_label](predicate_label.md) - The label of the predicate/relation of the mapping
 * [predicate_modifier](predicate_modifier.md) - A modifier for negating the prediate. See https://github.com/mapping-commons/sssom/issues/40 for discussion
 * [predicate_type](predicate_type.md) - The type of entity that is being mapped.
 * [publication_date](publication_date.md) - The date the mapping was published. This is different from the date the mapping was asserted.
 * [reviewer_id](reviewer_id.md) - Identifies the persons or groups that reviewed and confirmed the mapping. Recommended to be a (pipe-separated) list of ORCIDs or otherwise identifying URLs, but any identifying string (such as name and affiliation) is permissible.
 * [reviewer_label](reviewer_label.md) - A string identifying the reviewer of this mapping. In the spirit of provenance, consider to use author_id instead.
 * [see_also](see_also.md) - A URL specific for the mapping instance. E.g. for kboom we have a per-mapping image that shows surrounding axioms that drive probability. Could also be a github issue URL that discussed a complicated alignment
 * [semantic_similarity_measure](semantic_similarity_measure.md) - The measure used for computing the the semantic similarity score. To make processing this field as unambiguous as possible, we recommend using wikidata identifiers, but wikipedia pages could also be acceptable.
 * [semantic_similarity_score](semantic_similarity_score.md) - A score between 0 and 1 to denote the semantic similarity, where 1 denotes equivalence.
 * [subject_category](subject_category.md) - The conceptual category to which the subject belongs to. This can be a string denoting the category or a term from a controlled vocabulary.
 * [subject_id](subject_id.md) - The ID of the subject of the mapping.
 * [subject_label](subject_label.md) - The label of subject of the mapping
 * [subject_match_field](subject_match_field.md) - A tuple of fields (term annotations on the subject) that was used for the match.
 * [subject_preprocessing](subject_preprocessing.md) - Method of preprocessing applied to the fields of the subject. If different preprocessing steps were performed on different fields, it is recommended to store the match in separate rows.
 * [subject_source](subject_source.md) - URI of ontology source for the subject.
 * [subject_source_version](subject_source_version.md) - Version IRI or version string of the source of the subject term.
 * [subject_type](subject_type.md) - The type of entity that is being mapped.

### Enums

 * [entity_type_enum](entity_type_enum.md)
 * [mapping_cardinality_enum](mapping_cardinality_enum.md)
 * [predicate_modifier_enum](predicate_modifier_enum.md)
 * [preprocessing_method_enum](preprocessing_method_enum.md)

### Subsets


### Types


#### Built in

 * **Bool**
 * **Decimal**
 * **ElementIdentifier**
 * **NCName**
 * **NodeIdentifier**
 * **URI**
 * **URIorCURIE**
 * **XSDDate**
 * **XSDDateTime**
 * **XSDTime**
 * **float**
 * **int**
 * **str**

#### Defined

 * [EntityReference](types/EntityReference.md)  ([Uriorcurie](types/Uriorcurie.md))  - A reference to a mapped entity. This is represented internally as a string, and as a resource in RDF
 * [Boolean](types/Boolean.md)  (**Bool**)  - A binary (true or false) value
 * [Date](types/Date.md)  (**XSDDate**)  - a date (year, month and day) in an idealized calendar
 * [Datetime](types/Datetime.md)  (**XSDDateTime**)  - The combination of a date and time
 * [Decimal](types/Decimal.md)  (**Decimal**)  - A real number with arbitrary precision that conforms to the xsd:decimal specification
 * [Double](types/Double.md)  (**float**)  - A real number that conforms to the xsd:double specification
 * [Float](types/Float.md)  (**float**)  - A real number that conforms to the xsd:float specification
 * [Integer](types/Integer.md)  (**int**)  - An integer
 * [Ncname](types/Ncname.md)  (**NCName**)  - Prefix part of CURIE
 * [Nodeidentifier](types/Nodeidentifier.md)  (**NodeIdentifier**)  - A URI, CURIE or BNODE that represents a node in a model.
 * [Objectidentifier](types/Objectidentifier.md)  (**ElementIdentifier**)  - A URI or CURIE that represents an object in the model.
 * [String](types/String.md)  (**str**)  - A character string
 * [Time](types/Time.md)  (**XSDTime**)  - A time object represents a (local) time of day, independent of any particular day
 * [Uri](types/Uri.md)  (**URI**)  - a complete URI
 * [Uriorcurie](types/Uriorcurie.md)  (**URIorCURIE**)  - a URI or a CURIE
